==> openGion6.9.1.0_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE16S.sql <==
/****************************************************************************/
/* GE16 ( ﾕｰｻﾞｰﾊﾟﾗﾒｰﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2017/07/18 12:28:34                                            */
/****************************************************************************/

CREATE TABLE GE16 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (  10 )                 NOT NULL                                                                                                        /*  20 ﾕｰｻﾞｰID      */
 , PARAM_ID     VARCHAR (  50 )                 NOT NULL                                                                                                        /*  30 ﾊﾟﾗﾒｰﾀID     */
 , PARAM        VARCHAR ( 500 )                                                                                                                                 /*  40 設定値       */
 , FGCRYPT      VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                                                                        /* 120 暗号化ﾌﾗｸﾞ   */
 , UNIQ         BIGINT                          NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE16 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                                                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                                                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                                                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                                                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                                                                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                                                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                                                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                                                                                 /* 890 更新者       */
);

==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE16S.sql <==
/****************************************************************************/
/* GE16 ( ﾕｰｻﾞｰﾊﾟﾗﾒｰﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GE16 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                                                                        /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (  10 )                 NOT NULL                                                                                                        /*  20 ﾕｰｻﾞｰID      */
 , PARAM_ID     VARCHAR (  50 )                 NOT NULL                                                                                                        /*  30 ﾊﾟﾗﾒｰﾀID     */
 , PARAM        VARCHAR ( 500 )                                                                                                                                 /*  40 設定値       */
 , FGCRYPT      VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                                                                        /* 120 暗号化ﾌﾗｸﾞ   */
 , UNIQ         BIGINT                          NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE16 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                                                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                                                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                                                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                                                                                 /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                                                                                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                                                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                                                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                                                                                 /* 890 更新者       */
);
